@@ -10,17 +10,20 @@ use strict;
 use warnings;
 package Games::Go::AGA::BayRate::GSL::Multimin;
 
-our $VERSION = '0.081'; # VERSION
+use File::Copy; # for copy
+
+our $VERSION = '0.084'; # VERSION
 my $libs;
 BEGIN {
     if (not -f 'swigperlrun.h') {
-        print "swigperlrun.h not available, attempting to create it:\n",
+        print STDERR "\n\nswigperlrun.h not available, attempting to create it:\n",
               "    executing swig -perl -external-runtime\n";
         system "swig -perl -external-runtime";
         if (not -f 'swigperlrun.h') {
-            die "Failed to create swigperlrun.h (is swig installed?), can't use this module";
+            print STDERR "Failed to create swigperlrun.h (is swig installed?), I'll copy from my version, cross your fingers...\n";
+            copy('my_swigperlrun', 'swigperlrun.h') or die "Failed to copy my_swigperlrun: $!\n";
         }
-        print "You may remove swigperlrun.h when this program completes.\n",
+        print STDERR "    You may remove swigperlrun.h when this program completes.\n\n",
     }
 
     eval {
